==> messaging-5.16.1-sources.jar: com/liveperson/messaging/commands/pusher/RegisterPusherCommand.java <==
package com.liveperson.messaging.commands.pusher;

import androidx.annotation.Nullable;
import android.text.TextUtils;

import com.liveperson.infra.Command;
import com.liveperson.infra.ICallback;
import com.liveperson.infra.PushType;
import com.liveperson.infra.auth.LPAuthenticationParams;
import com.liveperson.infra.log.LPLog;
import com.liveperson.infra.managers.PreferenceManager;
import com.liveperson.infra.network.http.requests.PushRequest;
import com.liveperson.infra.preferences.PushMessagePreferences;
import com.liveperson.messaging.Messaging;
import com.liveperson.messaging.model.SynchronizedAuthenticationCompletedCallback;

import java.util.List;

import static com.liveperson.infra.errors.ErrorCode.*;
import static com.liveperson.infra.managers.PreferenceManager.APP_ID_PREFERENCE_KEY;
import static com.liveperson.infra.managers.PreferenceManager.CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY;
import static com.liveperson.infra.managers.PreferenceManager.PUSHER_DEVICE_TOKEN_PREFERENCE_KEY;

/**
 * Created by Ilya Gazman on 11/26/2015.
 */
public class RegisterPusherCommand implements Command {

    private static final String TAG = "RegisterPusherCommand";
    private static final String PUSHER_URL = "https://%s/api/account/%s/device/register";
    private final Messaging mController;
    private final LPAuthenticationParams mLpAuthParams;
    private String mBrandId;
    private String deviceToken;
    private String platform;
    private String mAppId;
    @Nullable
    private ICallback<Void, Exception> mRegistrationCompletedCallback;
    private PusherHelper pusherHelper;

    public RegisterPusherCommand(Messaging messagingController, String brandId, String appId, String token, PushType pushType, LPAuthenticationParams lpAuthParams, @Nullable final ICallback<Void, Exception> registrationCompletedCallback) {
        mController = messagingController;
        mBrandId = brandId;
        deviceToken = token;
        platform = pushType.getPlatform();
        mAppId = appId;
        mLpAuthParams = lpAuthParams;
        mRegistrationCompletedCallback = registrationCompletedCallback;
    }

    @Override
    public void execute() {
        pusherHelper = new PusherHelper(mBrandId, mController);

        LPLog.INSTANCE.i(TAG, "execute with token " + LPLog.INSTANCE.mask(deviceToken));
        if (TextUtils.isEmpty(mAppId)) {
            mAppId = PreferenceManager.getInstance().getStringValue(APP_ID_PREFERENCE_KEY, mBrandId, "");
        } else {
            //Save appId in case it's needed for Messaging.liteLogout()
            PreferenceManager.getInstance().setStringValue(APP_ID_PREFERENCE_KEY, mBrandId, mAppId);
        }
        if (TextUtils.isEmpty(deviceToken)) {
            deviceToken = PreferenceManager.getInstance().getStringValue(PUSHER_DEVICE_TOKEN_PREFERENCE_KEY, mBrandId, "");
            if (TextUtils.isEmpty(deviceToken)) {
                LPLog.INSTANCE.w(TAG, "device token is empty. skip register pusher.");
                return;
            }
        } else {
            //Save device token. It's needed to register pusher after consumer switch.(lite logout)
            PreferenceManager.getInstance().setStringValue(PUSHER_DEVICE_TOKEN_PREFERENCE_KEY, mBrandId, deviceToken);
        }

        boolean isExecuting = new SynchronizedAuthenticationCompletedCallback(mController.mAccountsController, mBrandId, new ICallback<Void, Exception> (){
            @Override
            public void onSuccess(Void value) {
                List<String> certificates = pusherHelper.getCertificatePinningKeys();
                String pusherDomain = pusherHelper.getPusherDomain();
                if (TextUtils.isEmpty(pusherDomain)) {
                        LPLog.INSTANCE.e(TAG, ERR_0000014C, "pusherDomain does not exists. Failed to register push");
                        reportError(new Exception("Pusher domain is empty!, SDK may not initialized!"));
                        return;
                }

                String pusherURL = String.format(PUSHER_URL, pusherDomain, mBrandId);

                String consumerId = pusherHelper.getConsumerId();
                if (TextUtils.isEmpty(consumerId)) {
                    LPLog.INSTANCE.w(TAG, "fetchConsumerIdAndSendRequest: Cannot get consumerId. Quit register pusher");
                    reportError(new Exception("Failed to register pusher. Error: Missing consumerID"));
                    return;
                }
                sendRequest(pusherURL, consumerId, certificates);
            }

            @Override
            public void onError(Exception exception) {
               reportError(exception);
            }

            private void sendRequest(String pusherURL, String consumerId, List<String> certificates) {
                LPLog.INSTANCE.i(TAG, "Running register pusher with token " + LPLog.INSTANCE.mask(deviceToken));
                String token = pusherHelper.getAuthToken();
                String authType = pusherHelper.getAuthType();
                PushMessagePreferences.INSTANCE.setPushPlatform(platform);

                new PushRequest(pusherURL, consumerId, mAppId, deviceToken, token, platform, authType, certificates)
                        .setCallback(new ICallback<Void, Exception>() {
                            @Override
                            public void onSuccess(Void value) {
                                PreferenceManager.getInstance().setBooleanValue(PreferenceManager.IS_PUSHER_REGISTERED_PREFERENCE_KEY, mBrandId, true);
                                PreferenceManager.getInstance().remove(CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY, mBrandId);
                                if (mRegistrationCompletedCallback != null) {
                                    mRegistrationCompletedCallback.onSuccess(value);
                                }
                            }

                            @Override
                            public void onError(Exception exception) {
                                if (mRegistrationCompletedCallback != null) {
                                    mRegistrationCompletedCallback.onError(exception);
                                }
                            }
                        })
                        .execute();
            }

            /**
             * Report error back to host app via callback
             * @param error error to return in the form of Exception
             */
            private void reportError(Exception error) {
                if (mRegistrationCompletedCallback != null) {
                    mRegistrationCompletedCallback.onError(error);
                }
            }

        }).executeWithReturnValue();

        //in case we have valid jwt we will execute the register request. otherwise, we'll try to connect.
        if (!isExecuting && mLpAuthParams != null){
            mController.connect(mBrandId, mLpAuthParams, null, true);
        }
    }
}

==> messaging-5.24.1-sources.jar: com/liveperson/messaging/commands/pusher/RegisterPusherCommand.java <==
package com.liveperson.messaging.commands.pusher;

import androidx.annotation.Nullable;
import android.text.TextUtils;

import com.liveperson.infra.Command;
import com.liveperson.infra.ICallback;
import com.liveperson.infra.PushType;
import com.liveperson.infra.auth.LPAuthenticationParams;
import com.liveperson.infra.log.LPLog;
import com.liveperson.infra.managers.PreferenceManager;
import com.liveperson.infra.network.http.requests.PushRequest;
import com.liveperson.infra.preferences.PushMessagePreferences;
import com.liveperson.messaging.Messaging;
import com.liveperson.messaging.model.SynchronizedAuthenticationCompletedCallback;

import java.util.List;

import static com.liveperson.infra.errors.ErrorCode.*;
import static com.liveperson.infra.managers.PreferenceManager.APP_ID_PREFERENCE_KEY;
import static com.liveperson.infra.managers.PreferenceManager.CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY;
import static com.liveperson.infra.managers.PreferenceManager.PUSHER_DEVICE_TOKEN_PREFERENCE_KEY;

/**
 * Created by Ilya Gazman on 11/26/2015.
 */
public class RegisterPusherCommand implements Command {

    private static final String TAG = "RegisterPusherCommand";
    private static final String PUSHER_URL = "https://%s/api/account/%s/device/register";
    private final Messaging mController;
    private final LPAuthenticationParams mLpAuthParams;
    private String mBrandId;
    private String deviceToken;
    private String platform;
    private String mAppId;
    @Nullable
    private ICallback<Void, Exception> mRegistrationCompletedCallback;
    private PusherHelper pusherHelper;

    public RegisterPusherCommand(Messaging messagingController, String brandId, String appId, String token, PushType pushType, LPAuthenticationParams lpAuthParams, @Nullable final ICallback<Void, Exception> registrationCompletedCallback) {
        mController = messagingController;
        mBrandId = brandId;
        deviceToken = token;
        platform = pushType.getPlatform();
        mAppId = appId;
        mLpAuthParams = lpAuthParams;
        mRegistrationCompletedCallback = registrationCompletedCallback;
    }

    @Override
    public void execute() {
        pusherHelper = new PusherHelper(mBrandId, mController);

        LPLog.INSTANCE.i(TAG, "execute with token " + LPLog.INSTANCE.mask(deviceToken));
        if (TextUtils.isEmpty(mAppId)) {
            mAppId = PreferenceManager.getInstance().getStringValue(APP_ID_PREFERENCE_KEY, mBrandId, "");
        } else {
            //Save appId in case it's needed for Messaging.liteLogout()
            PreferenceManager.getInstance().setStringValue(APP_ID_PREFERENCE_KEY, mBrandId, mAppId);
        }
        if (TextUtils.isEmpty(deviceToken)) {
            deviceToken = PreferenceManager.getInstance().getStringValue(PUSHER_DEVICE_TOKEN_PREFERENCE_KEY, mBrandId, "");
            if (TextUtils.isEmpty(deviceToken)) {
                LPLog.INSTANCE.w(TAG, "device token is empty. skip register pusher.");
                reportError(new IllegalStateException("Failed to register pusher. Missing device token."));
                return;
            }
        } else {
            //Save device token. It's needed to register pusher after consumer switch.(lite logout)
            PreferenceManager.getInstance().setStringValue(PUSHER_DEVICE_TOKEN_PREFERENCE_KEY, mBrandId, deviceToken);
        }

        boolean isExecuting = new SynchronizedAuthenticationCompletedCallback(mController.mAccountsController, mBrandId, new ICallback<Void, Exception> (){
            @Override
            public void onSuccess(Void value) {
                List<String> certificates = pusherHelper.getCertificatePinningKeys();
                String pusherDomain = pusherHelper.getPusherDomain();
                if (TextUtils.isEmpty(pusherDomain)) {
                        LPLog.INSTANCE.e(TAG, ERR_0000014C, "pusherDomain does not exists. Failed to register push");
                        reportError(new Exception("Pusher domain is empty!, SDK may not initialized!"));
                        return;
                }

                String pusherURL = String.format(PUSHER_URL, pusherDomain, mBrandId);

                String consumerId = pusherHelper.getConsumerId();
                if (TextUtils.isEmpty(consumerId)) {
                    LPLog.INSTANCE.w(TAG, "fetchConsumerIdAndSendRequest: Cannot get consumerId. Quit register pusher");
                    reportError(new Exception("Failed to register pusher. Error: Missing consumerID"));
                    return;
                }
                sendRequest(pusherURL, consumerId, certificates);
            }

            @Override
            public void onError(Exception exception) {
               reportError(exception);
            }

            private void sendRequest(String pusherURL, String consumerId, List<String> certificates) {
                LPLog.INSTANCE.i(TAG, "Running register pusher with token " + LPLog.INSTANCE.mask(deviceToken));
                String token = pusherHelper.getAuthToken();
                String authType = pusherHelper.getAuthType();
                PushMessagePreferences.INSTANCE.setPushPlatform(platform);

                new PushRequest(pusherURL, consumerId, mAppId, deviceToken, token, platform, authType, certificates, true)
                        .setCallback(new ICallback<Void, Exception>() {
                            @Override
                            public void onSuccess(Void value) {
                                PreferenceManager.getInstance().setBooleanValue(PreferenceManager.IS_PUSHER_REGISTERED_PREFERENCE_KEY, mBrandId, true);
                                PreferenceManager.getInstance().remove(CONSUMER_UNREGISTER_PUSHER_PREFERENCE_KEY, mBrandId);
                                if (mRegistrationCompletedCallback != null) {
                                    mRegistrationCompletedCallback.onSuccess(value);
                                }
                            }

                            @Override
                            public void onError(Exception exception) {
                                if (mRegistrationCompletedCallback != null) {
                                    mRegistrationCompletedCallback.onError(exception);
                                }
                            }
                        })
                        .execute();
            }

            /**
             * Report error back to host app via callback
             * @param error error to return in the form of Exception
             */


        }).executeWithReturnValue();

        //in case we have valid jwt we will execute the register request. otherwise, we'll try to connect.
        if (!isExecuting && mLpAuthParams != null){
            mController.connect(mBrandId, mLpAuthParams, null, true);
        }
    }

    private void reportError(Exception error) {
        if (mRegistrationCompletedCallback != null) {
            mRegistrationCompletedCallback.onError(error);
        }
    }
}
